# Contributing to GAME SDK

There are various ways you can contribute to the GAME SDK, whether it's fixing bugs, adding new plugins, or improving the documentation.

### Submitting Code (e.g. plugins)
1. **Fork** the repository and clone it to your local machine.
2. **Create a Branch** for your changes.
3. **Make Changes** to address the issue or add the feature.
4. **Commit** with a message that clearly explains your change.
5. **Push** the branch to your fork and submit a pull request.
6. **Label** the pull request appropriately based on the [label definitions](#label-definitions)
   
### Reporting Bugs
- Open an issue in the [Issues](https://github.com/game-by-virtuals/game-python/issues) tab and tag it as a `bug`.
  
### Suggesting Enhancements
- Open an issue in the [Issues](https://github.com/your-username/my-project/issues) tab and tag it as an `enhancement`.

## Label Definitions

Please tag issues and pull requests appropriately, based on the definition below:
- **plugin**: A plugin contribution.
- **bug**: A problem that needs fixing.
- **enhancement**: A requested enhancement.
- **help wanted**: A task that is open for anyone to work on.
- **documentation**: Documentation changes.